#ifndef __PVFS_V1_XFER_H
#define __PVFS_V1_XFER_H

/*
 * pvfs_v1_xfer.h copyright (c) 1999 Rob Ross and Phil Carns,
 * all rights reserved.
 *
 * Written by Rob Ross and Phil Carns.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation; either version 2 of the License,
 * or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * Contact:  Rob Ross   rbross@parl.clemson.edu
 *           Phil Carns pcarns@parl.clemson.edu
 */

#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <arpa/inet.h>
#include <malloc.h>

#ifdef LINUX
#include <linux/types.h>
#include <linux/dirent.h>
#endif

#include <ll_pvfs.h>

/* pvfs_comm_init()
 *
 * Sets up any necessary data structures for use in PVFS data transfer.
 * Should be called once before any transfers take place.
 *
 * Returns 0 on success, or -errno on failure.
 */
int pvfs_comm_init(void);

/* do_pvfs_op(op, resp)
 *
 * Performs a PVFS operation.  See ll_pvfs.h for the valid operation
 * types and the structures involved.
 *
 * Returns 0 on success, -errno on failure.
 */
int do_pvfs_op(struct pvfs_upcall *op, struct pvfs_downcall *resp);

/* pvfs_comm_shutdown()
 *
 * Performs any operations necessary to cleanly shut down PVFS
 * communication.  Should be called once after all desired communication
 * is complete.
 */
void pvfs_comm_shutdown(void);

/* pvfs_comm_idle()
 *
 * Performs operations associated with closing idle connections and open
 * files that are no longer in use.
 */
void pvfs_comm_idle(void);

/*
 * Local variables:
 *  c-indent-level: 3
 *  c-basic-offset: 3
 *  tab-width: 3
 * End:
 */

#endif
