#include <stdio.h>
#include <string.h>
#include <ll_pvfs.h>
#include <pvfs_v1_xfer.h>
#include <unistd.h>

static void init_up(struct pvfs_upcall *up);

int main(int argc, char **argv)
{
	int error, i;
	void *mgr;
	struct pvfs_upcall up;
	struct pvfs_downcall down;
	char name[1024] = "localhost:3000/pvfs";
	struct pvfs_dirent *dp;
	char buf[4096] = "this is some test text.";

	pvfs_comm_init();

	if (argc > 1) strcpy(name, argv[1]);

#if 0
	/* RENAME */
	init_up(&up);
	up.type = RENAME_OP;
	strncpy(up.u.rename.new_name, "localhost:3000/pvfs/foo", PVFSNAMELEN);
	strncpy(up.v1.fhname, name, PVFSNAMELEN);

	error = do_pvfs_op(&up, &down);
	if (error) {
		errno = -error;
		perror("do_pvfs_op");
		return -1;
	}
#endif

#if 1
	/* CREATE */
	init_up(&up);
	up.type = CREATE_OP;
	up.u.create.meta.valid = V_MODE | V_UID | V_GID;
	up.u.create.meta.uid = 0;
	up.u.create.meta.gid = 0;
	up.u.create.meta.mode = 0777;
	up.u.create.phys.dist = DIST_RROBIN;
	up.u.create.phys.blksize = 16384;
	up.u.create.phys.nodect = 1;
	strncpy(up.u.create.name, name, PVFSNAMELEN);
	strncpy(up.v1.fhname, name, PVFSNAMELEN);

	error = do_pvfs_op(&up, &down);
	if (error) {
		errno = -error;
		perror("do_pvfs_op");
		return -1;
	}
#endif

#if 1
	/* GETMETA */
	init_up(&up);
	up.type = GETMETA_OP;
	strncpy(up.v1.fhname, name, PVFSNAMELEN);

	error = do_pvfs_op(&up, &down);
	if (error) {
		errno = -error;
		perror("do_pvfs_op");
		return -1;
	}
	printf("%s:\nhandle = %ld, size = %ld, mode = %o\n",
		name, (long) down.u.getmeta.meta.handle, (long) down.u.getmeta.meta.size,
		down.u.getmeta.meta.mode);
#endif

#if 1
	/* WRITE */
	init_up(&up);
	up.type = WRITE_OP;
	up.u.rw.handle = down.u.getmeta.meta.handle;
	up.u.rw.io.type = IO_CONTIG;
	up.u.rw.io.u.contig.off = 8192;
	up.u.rw.io.u.contig.size = 4096;
	up.xfer.ptr = buf;
	up.xfer.size = 4096;
	strncpy(up.v1.fhname, name, PVFSNAMELEN);

	error = do_pvfs_op(&up, &down);
	if (error) {
		errno = -error;
		perror("do_pvfs_op");
		return -1;
	}
#endif

#if 0
	/* SETMETA */
	init_up(&up); /* this sets the uid and gid to the process's... */
	up.proc.uid = 0;
	up.proc.gid = 0;
	up.type = SETMETA_OP;
	up.u.setmeta.meta.valid = V_MODE;
	up.u.setmeta.meta.mode = 0755;
	strncpy(up.v1.fhname, name, PVFSNAMELEN);

	error = do_pvfs_op(&up, &down);
	if (error) {
		errno = -error;
		perror("do_pvfs_op");
		return -1;
	}
	printf("%s:\nhandle = %ld, size = %ld, mode = %o\n",
		name, (long) down.u.setmeta.meta.handle, (long) down.u.setmeta.meta.size,
		down.u.setmeta.meta.mode);
#endif

#if 0
	/* GETDENTS */
	init_up(&up);
	up.type = GETDENTS_OP;
	up.u.getdents.off = 0;
	up.u.getdents.count = 3;
	strncpy(up.v1.fhname, name, PVFSNAMELEN);

	error = do_pvfs_op(&up, &down);
	if (error) {
		errno = -error;
		perror("do_pvfs_op");
		return -1;
	}
	dp = (struct pvfs_dirent *)down.xfer.ptr;
	printf("getdents output:\n");
	for (i = 0; i < down.u.getdents.count; i++) {
		printf("handle = %ld, name = %s\n", (long) dp->handle, dp->name);
		dp++;
	}
#endif

#if 0
	/* REMOVE */
	init_up(&up);
	up.type = REMOVE_OP;
	strncpy(up.v1.fhname, name, PVFSNAMELEN);

	error = do_pvfs_op(&up, &down);
	if (error) {
		errno = -error;
		perror("do_pvfs_op (remove)");
		return -1;
	}
#endif

	pvfs_comm_idle();
	pvfs_comm_idle();

	pvfs_comm_shutdown();

	return 0;
}

static void init_up(struct pvfs_upcall *up)
{
	up->magic = PVFS_UPCALL_MAGIC;
	up->seq = 1;
	up->proc.uid = getuid();
	up->proc.gid = getgid();

}










